| Title: | Longitudinal system suitability monitoring and quality control for proteomic experiments |
|---|---|
| Description: | MSstatsQC is an R package which provides longitudinal system suitability monitoring and quality control tools for proteomic experiments. |
| Authors: | Eralp Dogu [aut, cre] (ORCID: <https://orcid.org/0000-0002-8256-7304>), Sara Taheri [aut] (ORCID: <https://orcid.org/0000-0002-6554-9083>), Olga Vitek [aut] (ORCID: <https://orcid.org/0000-0003-1728-1104>) |
| Maintainer: | Eralp Dogu <[email protected]> |
| License: | Artistic License 2.0 |
| Version: | 2.31.0 |
| Built: | 2026-05-30 09:43:12 UTC |
| Source: | https://github.com/bioc/MSstatsQC |
A function to identify the time of a change in the mean or variability of a metric
ChangePointEstimator( data = NULL, peptide, L = 1, U = 5, metric, normalization = TRUE, ytitle = "Change Point Plot - mean", type = "mean", selectMean = NULL, selectSD = NULL )ChangePointEstimator( data = NULL, peptide, L = 1, U = 5, metric, normalization = TRUE, ytitle = "Change Point Plot - mean", type = "mean", selectMean = NULL, selectSD = NULL )
data |
comma-separated (.csv), metric file. It should contain a "Precursor" column and the metrics columns. It should also include "Annotations" for each observation. |
peptide |
the name of precursor of interest. |
L |
Lower bound of the guide set. |
U |
Upper bound of the guide set. |
metric |
the name of metric of interest. |
normalization |
TRUE metric is standardized and FALSE if not standardized. |
ytitle |
the y-axis title of the plot. Defaults to "Change Point Plot - mean". The x-axis title is by default "QCno-name of peptide" |
type |
the type of the control chart. Two values can be assigned, "mean" or "variability". Default is "mean". |
selectMean |
the mean of a metric. It is used when mean is known. It is NULL when mean is not known. The default is NULL. |
selectSD |
the standard deviation of a metric. It is used when standard deviation is known. It is NULL when mean is not known. The default is NULL. |
A plot of likelihood statistics versus time per peptide and metric generated from CP.data.prepare data frame.
# First process the data to make sure it's ready to use sampleData <- DataProcess(S9Site54) head(sampleData) # Find the name of the peptides levels(sampleData$Precursor) # Calculate change point statistics ChangePointEstimator(data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime") ChangePointEstimator( data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime", ytitle = "Change Point Plot - variability", type = "variability" ) ChangePointEstimator( data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime", selectMean = 27.78, selectSD = 8.19 ) ChangePointEstimator(data = sampleData, peptide = "DDGSWEVIEGYR", metric = "TotalArea") ChangePointEstimator( data = sampleData, peptide = "DDGSWEVIEGYR", metric = "TotalArea", selectMean = 35097129, selectSD = 34132861 ) ChangePointEstimator(data = sampleData, peptide = "TAAYVNAIEK", metric = "MaxFWHM")# First process the data to make sure it's ready to use sampleData <- DataProcess(S9Site54) head(sampleData) # Find the name of the peptides levels(sampleData$Precursor) # Calculate change point statistics ChangePointEstimator(data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime") ChangePointEstimator( data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime", ytitle = "Change Point Plot - variability", type = "variability" ) ChangePointEstimator( data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime", selectMean = 27.78, selectSD = 8.19 ) ChangePointEstimator(data = sampleData, peptide = "DDGSWEVIEGYR", metric = "TotalArea") ChangePointEstimator( data = sampleData, peptide = "DDGSWEVIEGYR", metric = "TotalArea", selectMean = 35097129, selectSD = 34132861 ) ChangePointEstimator(data = sampleData, peptide = "TAAYVNAIEK", metric = "MaxFWHM")
A function to create cumulative sum charts for mean (CUSUMm) and cumulative sum charts for variability (CUSUMv) control charts
CUSUMChart( data = NULL, peptide, L = 1, U = 5, metric, normalization = TRUE, ytitle = "CUSUMm", type = "mean", selectMean = NULL, selectSD = NULL, referenceValue = 0.5, decisionInterval = 5 )CUSUMChart( data = NULL, peptide, L = 1, U = 5, metric, normalization = TRUE, ytitle = "CUSUMm", type = "mean", selectMean = NULL, selectSD = NULL, referenceValue = 0.5, decisionInterval = 5 )
data |
comma-separated (.csv), metric file. It should contain a "Precursor" column and the metrics columns. It should also include "Annotations" for each observation. |
peptide |
the name of precursor of interest. |
L |
Lower bound of the guide set. |
U |
Upper bound of the guide set. |
metric |
the name of metric of interest. |
normalization |
TRUE if metric is standardized and FALSE if not standardized. |
ytitle |
the y-axis title of the plot. Defaults to "CUSUMm". The x-axis title is by default "Time : name of peptide" |
type |
the type of the control chart. Two values can be assigned, "mean" or "variability". Default is "mean" |
selectMean |
the mean of a metric. It is used when mean is known. It is NULL when mean is not known. The default is NULL. |
selectSD |
the standard deviation of a metric. It is used when standard deviation is known. It is NULL when mean is not known. The default is NULL. |
referenceValue |
the value that is used to tune the control chart for a proper shift size |
decisionInterval |
the threshold to detect an out-of-control observation |
A plot of pozitive and negative CUSUM statistics versus time per peptide and metric generated from CUSUM.data.prepare data frame.
# First process the data to make sure it's ready to use sampleData <- DataProcess(S9Site54) head(sampleData) # Find the name of the peptides levels(sampleData$Precursor) # Calculate CUSUM statistics CUSUMChart(data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime") CUSUMChart( data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime", ytitle = "CUSUMv", type = "variability" ) CUSUMChart( data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime", selectMean = 27.78, selectSD = 8.19 ) CUSUMChart(data = sampleData, peptide = "DDGSWEVIEGYR", metric = "TotalArea") CUSUMChart( data = sampleData, peptide = "DDGSWEVIEGYR", metric = "TotalArea", selectMean = 35097129, selectSD = 34132861 ) CUSUMChart(data = sampleData, peptide = "TAAYVNAIEK", metric = "MaxFWHM")# First process the data to make sure it's ready to use sampleData <- DataProcess(S9Site54) head(sampleData) # Find the name of the peptides levels(sampleData$Precursor) # Calculate CUSUM statistics CUSUMChart(data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime") CUSUMChart( data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime", ytitle = "CUSUMv", type = "variability" ) CUSUMChart( data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime", selectMean = 27.78, selectSD = 8.19 ) CUSUMChart(data = sampleData, peptide = "DDGSWEVIEGYR", metric = "TotalArea") CUSUMChart( data = sampleData, peptide = "DDGSWEVIEGYR", metric = "TotalArea", selectMean = 35097129, selectSD = 34132861 ) CUSUMChart(data = sampleData, peptide = "TAAYVNAIEK", metric = "MaxFWHM")
A data processing function
DataProcess(data = NULL)DataProcess(data = NULL)
data |
Comma-separated (*.csv), QC file format. It should contain a Precursor column and the metrics columns. |
A data frame that processes using input.sanity.check function.
# The data is "S9Site54" which is defined in the package. data <- DataProcess(S9Site54)# The data is "S9Site54" which is defined in the package. data <- DataProcess(S9Site54)
A function to create heatmaps to compare performance with user defined performance criteria
DecisionMap( data = NULL, method = "XmR", peptideThresholdRed = 0.7, peptideThresholdYellow = 0.5, L = 1, U = 5, type = "mean", title = "heatmap plot", listMean = NULL, listSD = NULL )DecisionMap( data = NULL, method = "XmR", peptideThresholdRed = 0.7, peptideThresholdYellow = 0.5, L = 1, U = 5, type = "mean", title = "heatmap plot", listMean = NULL, listSD = NULL )
data |
Comma-separated (*.csv), QC file format. It should contain a Precursor column and the metrics columns. |
method |
It is either "CUSUM" or "XmR" |
peptideThresholdRed |
Is a threshold that marks percentage of peptides above it red on the heatmap. Defaults to 0.7 |
peptideThresholdYellow |
Is a threshold that marks percentage of peptides above it and below the peptideThresholdRed, yellow on the heatmap. Defaults to 0.5 |
L |
Lower bound of the giude set. Defaults to 1 |
U |
Upper bound of the guide set. Defaults to 5 |
type |
can take two values, "mean" or "dispersion". Defaults to "mean" |
title |
the title of the plot. Defaults to "heatmap plot" |
listMean |
List of the means for the metrics. If you don't know the means leave it as NULL and they will be calculated automatically by using L and U. The default is NULL. |
listSD |
List of the standard deviations for the metrics. If you don't know the standard deviations leave it as NULL and they will be calculated automatically by using L and U. The default is NULL. |
A heatmap to aggregate results per metric generated from heatmap.DataFrame data frame.
# First process the data to make sure it's ready to use sampleData <- DataProcess(S9Site54) head(sampleData) # Draw Decision maker plot DecisionMap(data = sampleData, method = "CUSUM") DecisionMap(data = sampleData, method = "CUSUM", type = "variability") DecisionMap(data = sampleData, method = "XmR") DecisionMap(data = sampleData, method = "XmR", type = "variability")# First process the data to make sure it's ready to use sampleData <- DataProcess(S9Site54) head(sampleData) # Draw Decision maker plot DecisionMap(data = sampleData, method = "CUSUM") DecisionMap(data = sampleData, method = "CUSUM", type = "variability") DecisionMap(data = sampleData, method = "XmR") DecisionMap(data = sampleData, method = "XmR", type = "variability")
A function to summarize missing values
MissingDataMap(data)MissingDataMap(data)
data |
Processed data |
A plot of missing values.
# The data is "S9Site54" which is defined in the package. data <- DataProcess(S9Site54) MissingDataMap(data)# The data is "S9Site54" which is defined in the package. data <- DataProcess(S9Site54) MissingDataMap(data)
A function to convert MSnbase files to MSstatsQC format
MSnbaseToMSstatsQC(msfile)MSnbaseToMSstatsQC(msfile)
msfile |
data file to be converted |
A data frame that can be used with MSstatsQC
A csv file that is converted from raw files
library(RforProteomics) msfile <- getPXD000001mzXML() MSnbaseToMSstatsQC(msfile)library(RforProteomics) msfile <- getPXD000001mzXML() MSnbaseToMSstatsQC(msfile)
A function to test random forest classifiers for QC data
MSstatsQC.ML.deployR(Test.set, guide.set, rf_model)MSstatsQC.ML.deployR(Test.set, guide.set, rf_model)
Test.set |
comma-separated (.csv), metric file. It should contain a "Precursor" column and the metrics columns. It should also include "Annotations" for each run. |
guide.set |
comma-separated (.csv), metric file. It should contain a "Precursor" column and the metrics columns. It should also include "Annotations" for each run. |
rf_model |
the model that was trained previosly by MSstatsQC-ML training process |
Probability of failure predictions based on a trained model
S9Site54.dataML <- DataProcess(MSstatsQC::S9Site54[, ]) colnames(S9Site54.dataML)[1] <- c("idfile") colnames(S9Site54.dataML)[2] <- c("peptide") S9Site54.dataML$peptide <- as.factor(S9Site54.dataML$peptide) S9Site54.dataML$idfile <- as.numeric(S9Site54.dataML$idfile) S9Site54.dataML <- within(S9Site54.dataML, rm(Annotations, missing)) guide.set <- dplyr::filter(S9Site54.dataML, idfile <= 20) rf_model <- MSstatsQC.ML.trainR(guide.set, sim.size = 10) Test.set <- dplyr::filter(S9Site54.dataML, idfile > 20) MSstatsQC.ML.deployR(Test.set, guide.set, rf_model = rf_model) Test.set <- S9Site54.dataML MSstatsQC.ML.deployR(Test.set, guide.set, rf_model = rf_model)S9Site54.dataML <- DataProcess(MSstatsQC::S9Site54[, ]) colnames(S9Site54.dataML)[1] <- c("idfile") colnames(S9Site54.dataML)[2] <- c("peptide") S9Site54.dataML$peptide <- as.factor(S9Site54.dataML$peptide) S9Site54.dataML$idfile <- as.numeric(S9Site54.dataML$idfile) S9Site54.dataML <- within(S9Site54.dataML, rm(Annotations, missing)) guide.set <- dplyr::filter(S9Site54.dataML, idfile <= 20) rf_model <- MSstatsQC.ML.trainR(guide.set, sim.size = 10) Test.set <- dplyr::filter(S9Site54.dataML, idfile > 20) MSstatsQC.ML.deployR(Test.set, guide.set, rf_model = rf_model) Test.set <- S9Site54.dataML MSstatsQC.ML.deployR(Test.set, guide.set, rf_model = rf_model)
A function to train random forest classifiers for QC data
MSstatsQC.ML.sim.size.detectR(guide.set, sim.start, sim.end)MSstatsQC.ML.sim.size.detectR(guide.set, sim.start, sim.end)
guide.set |
comma-separated (.csv), metric file. It should contain a "Precursor" column and the metrics columns. It should also include "Annotations" for each run. |
sim.start |
enter min simulation size. |
sim.end |
enter max simulation size. |
a plot for sim.size vs performance
# First process the data to make sure it's ready to use S9Site54.dataML <- DataProcess(MSstatsQC::S9Site54[, ]) colnames(S9Site54.dataML)[1] <- c("idfile") colnames(S9Site54.dataML)[2] <- c("peptide") S9Site54.dataML$peptide <- as.factor(S9Site54.dataML$peptide) S9Site54.dataML$idfile <- as.numeric(S9Site54.dataML$idfile) S9Site54.dataML <- within(S9Site54.dataML, rm(Annotations, missing)) guide.set <- dplyr::filter(S9Site54.dataML, idfile <= 20) MSstatsQC.ML.sim.size.detectR(guide.set, sim.start = 10, sim.end = 2500)# First process the data to make sure it's ready to use S9Site54.dataML <- DataProcess(MSstatsQC::S9Site54[, ]) colnames(S9Site54.dataML)[1] <- c("idfile") colnames(S9Site54.dataML)[2] <- c("peptide") S9Site54.dataML$peptide <- as.factor(S9Site54.dataML$peptide) S9Site54.dataML$idfile <- as.numeric(S9Site54.dataML$idfile) S9Site54.dataML <- within(S9Site54.dataML, rm(Annotations, missing)) guide.set <- dplyr::filter(S9Site54.dataML, idfile <= 20) MSstatsQC.ML.sim.size.detectR(guide.set, sim.start = 10, sim.end = 2500)
A function to train random forest classifiers for QC data
MSstatsQC.ML.trainR( guide.set, sim.size, guide.set.annotations = NULL, nfolds = NULL, a = 1.5, b = 2 )MSstatsQC.ML.trainR( guide.set, sim.size, guide.set.annotations = NULL, nfolds = NULL, a = 1.5, b = 2 )
guide.set |
comma-separated (.csv), metric file. It should contain a "Precursor" column and the metrics columns. It should also include "Annotations" for each run. |
sim.size |
enter simulation size. |
guide.set.annotations |
comma-separated (.csv), metric file with annotations such as pass and fail. |
nfolds |
fold for cross validation |
a |
lower threshold to define shift size |
b |
upper threshold to define shift size |
A trained model and performance indicators from train/validation/test splits
S9Site54.dataML <- DataProcess(MSstatsQC::S9Site54[, ]) colnames(S9Site54.dataML)[1] <- c("idfile") colnames(S9Site54.dataML)[2] <- c("peptide") S9Site54.dataML$peptide <- as.factor(S9Site54.dataML$peptide) S9Site54.dataML$idfile <- as.numeric(S9Site54.dataML$idfile) S9Site54.dataML <- within(S9Site54.dataML, rm(Annotations, missing)) guide.set <- dplyr::filter(S9Site54.dataML, idfile <= 20) MSstatsQC.ML.trainR(guide.set, sim.size = 10)S9Site54.dataML <- DataProcess(MSstatsQC::S9Site54[, ]) colnames(S9Site54.dataML)[1] <- c("idfile") colnames(S9Site54.dataML)[2] <- c("peptide") S9Site54.dataML$peptide <- as.factor(S9Site54.dataML$peptide) S9Site54.dataML$idfile <- as.numeric(S9Site54.dataML$idfile) S9Site54.dataML <- within(S9Site54.dataML, rm(Annotations, missing)) guide.set <- dplyr::filter(S9Site54.dataML, idfile <= 20) MSstatsQC.ML.trainR(guide.set, sim.size = 10)
A function to convert mzQC files to MSstatsQC format
mzQCToMSstatsQC(mzQCfile)mzQCToMSstatsQC(mzQCfile)
mzQCfile |
data file to be converted |
A data frame that can be used with MSstatsQC
A csv file that is converted from raw files
library(RforProteomics) msfile <- getPXD000001mzXML() mzQCToMSstatsQC(msfile)library(RforProteomics) msfile <- getPXD000001mzXML() mzQCToMSstatsQC(msfile)
QC results generated from QCloud system
data(QCloudDDA)data(QCloudDDA)
csv
DDA QC data from QCloud System
An example dataset generated from QCloud system
head(QCloudDDA)head(QCloudDDA)
QC results generated from QCloud system
data(QCloudSRM)data(QCloudSRM)
csv
SRM QC data from QCloud System
An example dataset generated from QCloud system
head(QCloudSRM)head(QCloudSRM)
QC results generated from QuiC system
data(QuiCDIA)data(QuiCDIA)
csv
DIA iRT data from QuiC System
An example dataset generated from QuiC system
head(QuiCDIA)head(QuiCDIA)
A function to create radar plot to aggregate results from X and mR charts or CUSUMm and CUSUMv charts.
RadarPlot( data = NULL, L = 1, U = 5, method = "XmR", listMean = NULL, listSD = NULL )RadarPlot( data = NULL, L = 1, U = 5, method = "XmR", listMean = NULL, listSD = NULL )
data |
omma-separated (.csv), metric file. It should contain a "Precursor" column and the metrics columns. It should also include "Annotations" for each observation. |
L |
lower bound of the guide set. |
U |
upper bound of the guide set. |
method |
defines the method selected to construct control charts. |
listMean |
list of the means for each metric. It is used when mean is known. It is NULL when mean is not known. The default is NULL. |
listSD |
list of the standard deviations for each metric. It is used when standard deviation is known. It is NULL when mean is not known. The default is NULL. automatically by using L and U. The default is NULL. |
A radar plot to aggregate results per metric generated from XmR.Radar.Plot.DataFrame data frame or CUSUM.Radar.Plot.DataFrame data frame.
# First process the data to make sure it's ready to use sampleData <- DataProcess(S9Site54) head(sampleData) # Draw XmR radar plot RadarPlot(data = sampleData) RadarPlot(data = sampleData, method = "CUSUM") RadarPlot( data = sampleData, listMean = list( "BestRetentionTime" = 27.78, "TotalArea" = 35097129, "MaxFWHM" = 0.28, "MinStartTime" = 24 ), listSD = list( "BestRetentionTime" = 8.19, "TotalArea" = 34132861, "MaxFWHM" = 0.054, "MinStartTime" = 24 ) )# First process the data to make sure it's ready to use sampleData <- DataProcess(S9Site54) head(sampleData) # Draw XmR radar plot RadarPlot(data = sampleData) RadarPlot(data = sampleData, method = "CUSUM") RadarPlot( data = sampleData, listMean = list( "BestRetentionTime" = 27.78, "TotalArea" = 35097129, "MaxFWHM" = 0.28, "MinStartTime" = 24 ), listSD = list( "BestRetentionTime" = 8.19, "TotalArea" = 34132861, "MaxFWHM" = 0.054, "MinStartTime" = 24 ) )
A data processing function for removing missing values
RemoveMissing(data = NULL)RemoveMissing(data = NULL)
data |
Comma-separated (*.csv), QC file format. It should contain a Precursor column and the metrics columns. |
A data frame that processes using input.sanity.check function.
# The data is "S9Site54" which is defined in the package. data <- RemoveMissing(S9Site54)# The data is "S9Site54" which is defined in the package. data <- RemoveMissing(S9Site54)
A function to create river plot to aggregate results from X and mR charts or CUSUMm and CUSUMv charts.
RiverPlot( data = NULL, L = 1, U = 5, method = "XmR", listMean = NULL, listSD = NULL )RiverPlot( data = NULL, L = 1, U = 5, method = "XmR", listMean = NULL, listSD = NULL )
data |
omma-separated (.csv), metric file. It should contain a "Precursor" column and the metrics columns. It should also include "Annotations" for each observation. |
L |
lower bound of the guide set. |
U |
upper bound of the guide set. |
method |
defines the method selected to construct control charts. |
listMean |
list of the means for each metric. It is used when mean is known. It is NULL when mean is not known. The default is NULL. |
listSD |
list of the standard deviations for each metric. It is used when standard deviation is known. It is NULL when mean is not known. The default is NULL. |
A river plot to aggregate results per metric generated from XmR.Summary.DataFrame data frame or CUSUM.Summary.DataFrame data frame.
# First process the data to make sure it's ready to use sampleData <- DataProcess(S9Site54) head(sampleData) # Draw XmR summary plot RiverPlot(data = sampleData) RiverPlot( data = sampleData, L = 1, U = 20, method = "XmR", listMean = list( "BestRetentionTime" = 27.78, "TotalArea" = 35097129, "MaxFWHM" = 0.28, "MinStartTime" = 24 ), listSD = list( "BestRetentionTime" = 8.19, "TotalArea" = 34132861, "MaxFWHM" = 0.054, "MinStartTime" = 24 ) )# First process the data to make sure it's ready to use sampleData <- DataProcess(S9Site54) head(sampleData) # Draw XmR summary plot RiverPlot(data = sampleData) RiverPlot( data = sampleData, L = 1, U = 20, method = "XmR", listMean = list( "BestRetentionTime" = 27.78, "TotalArea" = 35097129, "MaxFWHM" = 0.28, "MinStartTime" = 24 ), listSD = list( "BestRetentionTime" = 8.19, "TotalArea" = 34132861, "MaxFWHM" = 0.054, "MinStartTime" = 24 ) )
system suitabilty testing results generated during CPTAC Study 9.1 for Site 54
data(S9Site54)data(S9Site54)
csv
CPTAC system suitability testing data for Site 54 from Study 9.1
An example dataset generated from CPTAC study 9.1
http://www.mcponline.org/content/early/2015/02/18/mcp.M114.047050
head(S9Site54)head(S9Site54)
A function to construct individual (X) and moving range (mR) control charts
XmRChart( data = NULL, peptide, L = 1, U = 5, metric, normalization = FALSE, ytitle = "Individual observations", type = "mean", selectMean = NULL, selectSD = NULL )XmRChart( data = NULL, peptide, L = 1, U = 5, metric, normalization = FALSE, ytitle = "Individual observations", type = "mean", selectMean = NULL, selectSD = NULL )
data |
comma-separated (.csv), metric file. It should contain a "Precursor" column and the metrics columns. It should also include "Annotations" for each observation. |
peptide |
the name of precursor of interest. |
L |
Lower bound of the guide set. |
U |
Upper bound of the guide set. |
metric |
the name of metric of interest. |
normalization |
TRUE if metric is standardized and FALSE if not standardized. |
ytitle |
the y-axis title of the plot. Defaults to "Individual observations". The x-axis title is by default "Time : name of peptide" |
type |
the type of the control chart. Two values can be assigned, "mean" or "variability". Default is "mean". |
selectMean |
the mean of a metric. It is used when mean is known. It is NULL when mean is not known. The default is NULL. |
selectSD |
the standard deviation of a metric. It is used when standard deviation is known. It is NULL when mean is not known. The default is NULL. |
A plot of individual values or moving ranges versus time per peptide and metric generated from XmR.data.prepare data frame.
# First process the data to make sure it's ready to use sampleData <- DataProcess(S9Site54) head(sampleData) # Find the name of the peptides levels(sampleData$Precursor) # Calculate X and mR statistics XmRChart(data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime") XmRChart( data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime", ytitle = "moving ranges", type = "variability" ) XmRChart( data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime", selectMean = 27.78, selectSD = 8.19 ) XmRChart(data = sampleData, peptide = "DDGSWEVIEGYR", metric = "TotalArea") XmRChart( data = sampleData, peptide = "DDGSWEVIEGYR", metric = "TotalArea", selectMean = 35097129, selectSD = 34132861 ) XmRChart(data = sampleData, peptide = "TAAYVNAIEK", metric = "MaxFWHM") XmRChart(data = sampleData, peptide = "LVNELTEFAK", metric = "MinStartTime")# First process the data to make sure it's ready to use sampleData <- DataProcess(S9Site54) head(sampleData) # Find the name of the peptides levels(sampleData$Precursor) # Calculate X and mR statistics XmRChart(data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime") XmRChart( data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime", ytitle = "moving ranges", type = "variability" ) XmRChart( data = sampleData, peptide = "VLVLDTDYK", metric = "BestRetentionTime", selectMean = 27.78, selectSD = 8.19 ) XmRChart(data = sampleData, peptide = "DDGSWEVIEGYR", metric = "TotalArea") XmRChart( data = sampleData, peptide = "DDGSWEVIEGYR", metric = "TotalArea", selectMean = 35097129, selectSD = 34132861 ) XmRChart(data = sampleData, peptide = "TAAYVNAIEK", metric = "MaxFWHM") XmRChart(data = sampleData, peptide = "LVNELTEFAK", metric = "MinStartTime")